Test scenario detection for duplicate groups.
This module provides functionality to analyze duplicate groups and categorize them by test scenario for validation purposes.
Re-exports
pub use detector::detect_scenarios;pub use fixtures::all_fixtures;pub use fixtures::ScenarioFixture;pub use generator::generate_image;pub use generator::ExifSpec;pub use generator::TestImage;pub use generator::TransformSpec;pub use report::format_report;pub use report::ScenarioReport;pub use scenarios::ScenarioMatch;pub use scenarios::TestScenario;