Module generator

Module generator 

Test image generator for integration tests.

Creates test images by transforming real base photos, ensuring CLIP-based duplicate detection works correctly in Immich.

Structs

ExifSpec
EXIF metadata specification.
TestImage
Complete test image specification.
TransformSpec
Transform specification for creating image variants.

Functions

generate_image
Generate a test image by transforming a base image.